Module fluent_syntax::parser [−][src]
AST, parser and serializer operations
This is an internal API used by FluentBundle for parsing an FTL syntax
into an AST that can be then resolved by the Resolver.
This module may be useful for tooling that operates on FTL syntax.
Re-exports
pub use self::parser::parse; |
Modules
| errors | |
| ftlstream | |
| parser | |
| stream |